//////////////////////////////////////////////////////////////////////
// Stingray Software - Objective Chart(tm) Copyright (c) 1996 Stingray
// Software Inc. All Rights Reserved. This source code is only
// intended as a supplement to the Stingray Objective Chart product.
// See the help files for detailed information regarding the use of these classes
// Written by Bob Powell (www.stingray.com)
/////////////////////////////////////////////////////////////////////

#include "stdafx.h"

#include "SECComDoc.h"
#include "SECDocManager.h"

SECDocManager::SECDocManager()
{
}

void SECDocManager::OnFileNew()
{
#ifndef __SECDOCMGR_NEW__
	CDocManager::OnFileNew(); // old behavior calls the old function
#else
	CDocTemplate *pTemplate;
	POSITION p;
	BOOL NoDocs=TRUE;
	
	for(p=m_templateList.GetHeadPosition();p!=NULL;)
	{
		pTemplate=(CDocTemplate *)m_templateList.GetNext(p);
		if(pTemplate->GetFirstDocPosition()!=NULL) // check to see if there is a document of this type open
			NoDocs=FALSE;// if there is flag it
	}
	
	if(NoDocs)
	{// open one of every sort
		for(p=m_templateList.GetHeadPosition();p!=NULL;)
		{
			pTemplate=(CDocTemplate *)m_templateList.GetNext(p);
			pTemplate->OpenDocumentFile(NULL);
		}
	}
	else
		CDocManager::OnFileNew(); // show the old chooser dialog anyway.
	
	// It could also be an option to open the document from the top of
	// the template list effectively hiding the other types. This may be useful for
	// applications which use a primary document type but need, from time to time, to
	// create a secondary style of document.
	
#endif
}

// SECDocManager
// Creation of specific document files with parameter passing via the filename string
void SECDocManager::OnFileNew(LPCTSTR DocIdent,	// Document name as given in the document template string held in the resource string table
							  LPCTSTR Params,	// Text string argument to pass to the new document in the form of a modified file name. NOTE: Your document must handle the filename parsing.
							  SECComDoc *pParent) // Pointer to the document which is opening the new document
{
	if (m_templateList.IsEmpty())
	{
		TRACE0("Error: no document templates registered with CWinApp.\n");
		AfxMessageBox(AFX_IDP_FAILED_TO_CREATE_DOC);
		return;
	}
	
	CDocTemplate* pTemplate=NULL;
	
	if (m_templateList.GetCount() > 1)
	{
		// more than one document template to choose from
		POSITION p;
		BOOL DocNotFound=TRUE;
		for(p=m_templateList.GetHeadPosition();p!=NULL;)
		{
			CString templatename;
			CDocTemplate* dt=(CDocTemplate *)m_templateList.GetNext(p);
			dt->GetDocString(templatename,CDocTemplate::fileNewName);
			if(templatename==DocIdent)
			{
				pTemplate=dt;
				DocNotFound=FALSE;
			}
		}
		
		// or bring up dialog prompting user to comply with the default
		if(DocNotFound)
		{
			CDocManager::OnFileNew(); //use the old system
			return;
		}
	}
	
	else
		pTemplate = (CDocTemplate*)m_templateList.GetHead();
	
	ASSERT(pTemplate != NULL);
	ASSERT_KINDOF(CDocTemplate, pTemplate);
	
	CDocument *newdoc=pTemplate->OpenDocumentFile(Params); // Params maybe NULL as in the default or may hold some significance for your document implememtation
	if(newdoc!=NULL)
	{
		if(newdoc->IsKindOf(RUNTIME_CLASS(SECComDoc)))
		{
			((SECComDoc *)newdoc)->SetParentPointer(pParent);
			pParent->NotifyLink((SECComDoc *)newdoc);
		}
		
	}
	// if returns NULL, the user has already been alerted
}

// Creates a specific type of new document and passes parameters via the stack
// Pointer to the newly opened document or NULL if that document is not a SECComDoc type
CDocument *SECDocManager::OnFileNew(LPCTSTR DocIdent,	// String containing the document name eg. "MyDoc"
									UINT nOpCode,		// Operation code of action to be executed
									UINT nSubCode,		// User defined subcode
									DWORD dwData,		// DWORD which may be used for 32 bit data including pointers, etc.
									SECComDoc *pParent)	// Pointer to the document which opens this one
									
{
	if (m_templateList.IsEmpty())
	{
		TRACE0("Error: no document templates registered with CWinApp.\n");
		AfxMessageBox(AFX_IDP_FAILED_TO_CREATE_DOC);
		return NULL;
	}
	
	CDocTemplate* pTemplate=NULL;
	
	if (m_templateList.GetCount() > 1)
	{
		// more than one document template to choose from
		POSITION p;
		BOOL DocNotFound=TRUE;
		for(p=m_templateList.GetHeadPosition();p!=NULL;)
		{
			CString templatename;
			CDocTemplate* dt=(CDocTemplate *)m_templateList.GetNext(p);
			dt->GetDocString(templatename,CDocTemplate::fileNewName);
			if(templatename==DocIdent)
			{
				pTemplate=dt;
				DocNotFound=FALSE;
			}
		}
		
		// or bring up dialog prompting user to comply with the default
		if(DocNotFound)
		{
			CDocManager::OnFileNew(); //use the old system
			return NULL;
		}
	}
	
	else
		pTemplate = (CDocTemplate*)m_templateList.GetHead();
	
	ASSERT(pTemplate != NULL);
	ASSERT_KINDOF(CDocTemplate, pTemplate);
	
	CDocument * newdoc=pTemplate->OpenDocumentFile(NULL); 
	if(newdoc!=NULL)
	{
		if(newdoc->IsKindOf(RUNTIME_CLASS(SECComDoc)))
		{
			((SECComDoc *)newdoc)->SetParentPointer(pParent);
			((SECComDoc *)newdoc)->ProcessDocumentCommand(nOpCode,nSubCode,dwData);
			if(pParent!=NULL)
				pParent->NotifyLink((SECComDoc *)newdoc);
			return newdoc;
		}
	}
	return NULL;
}

